//
//  CLBTableViewSection.h
//  CLBTableViewSection
//
//  Created by Philipp Steinacher on 31.12.11.
//

#import "CLBTableViewSection.h"

@implementation CLBTableViewSection
@synthesize title, cellHeights, cellBlocks, showIdentifierAsHeadline, cellSelectionBlocks;

- (id)initWithTitle:(NSString *)t
{
    self = [super init];
    
    if (self) {
        self.title = t;
        self.cellHeights = [NSMutableArray array];
        self.cellBlocks = [NSMutableArray array];
        self.cellSelectionBlocks = [NSMutableArray array];
    }
        
    return self;
}

- (void)registerRowAtIndex:(NSInteger)index withBlock:(UITableViewCell *(^)(UITableView *tableView))block height:(NSInteger)height andSelectionBlock:(void (^)(void))selectionBlock
{
    
    [cellHeights insertObject:[NSNumber numberWithInt:height] atIndex:index];
    [cellBlocks insertObject:block atIndex:index];
    [cellSelectionBlocks insertObject:selectionBlock atIndex:index];
}

- (void)registerRowWithBlock:(UITableViewCell *(^)(UITableView *))block
                   andHeight:(NSInteger)height
{
    block = [block copy];
    [cellHeights addObject:[NSNumber numberWithInt:height]];
    [cellBlocks addObject:block];
}

- (NSString *)title
{
    NSString *theTitle;
    
    if (showIdentifierAsHeadline) {
        theTitle = title;
    }
    
    return theTitle;
}

- (NSInteger)numberOfRows
{
    return [cellBlocks count];
}

- (NSInteger)cellHeightForIndex:(NSInteger)index
{
    return [[cellHeights objectAtIndex:index] intValue];
}

- (UITableViewCell *)cellForRow:(NSInteger)rowIndex inTableView:(UITableView *)tableView
{
    UITableViewCell *(^returnCell)(UITableView *) = [cellBlocks objectAtIndex:rowIndex];
        
    return returnCell(tableView);
}

- (void)didSelectCellAtRow:(NSInteger)row
{
    if ([cellSelectionBlocks count] > row) {
        void (^selection)(void) = [cellSelectionBlocks objectAtIndex:row];
        
        return selection();
    }
    
}


@end
