//
//  CLBTableViewSectionController.h
//  CLBTableViewSectionController
//
//  Created by Philipp Steinacher on 28.11.11.  
//

#import <Foundation/Foundation.h>
#import "CLBTableViewSection.h"

@class CLBTableViewSectionController;
@protocol CLBTableViewSectionControllerDelegate <NSObject>

@optional

- (void)tableViewSectionController:(CLBTableViewSectionController *) willResizeToHeight:(CGFloat)height;
- (void)tableViewSectionController:(CLBTableViewSectionController *) didResizeToHeight:(CGFloat)height;

@end

@interface CLBTableViewSectionController : NSObject <UITableViewDelegate, UITableViewDataSource> {
    // Options
    
    BOOL shouldAdaptToSizeOfAllCells;
    
    // Private parts
    
    @private
    
    // The UITableView which will be controlled by CLBTableViewSectionController
    UITableView *theTableView;
    
    // The delegate which handles event notifications
    
    id <CLBTableViewSectionControllerDelegate> delegate;
    
    // Section handling
    NSMutableArray *sections;
    NSMutableArray *sectionNames;
}

@property (nonatomic, strong) UITableView *theTableView;
@property (nonatomic, strong) id <CLBTableViewSectionControllerDelegate> delegate;
@property (nonatomic, assign) BOOL shouldAdaptToSizeOfAllCells;

- (id)initWithTableView:(UITableView *)tableView;

//  Section handling

- (void)addSection:(CLBTableViewSection *)section withIdentifier:(NSString *)identfier;
- (void)insertSection:(CLBTableViewSection *)section atIndex:(NSInteger)index withIdentifier:(NSString *)identifier;
- (void)insertSection:(CLBTableViewSection *)section beforeSection:(NSString *)sectionIdentifier withIdentifier:(NSString *)identifier;
- (void)insertSection:(CLBTableViewSection *)section afterSection:(NSString *)sectionIdentifier withIdentifier:(NSString *)identifier;

- (void)removeAllSections;
- (void)removeSectionAtIndex:(NSInteger)index;
- (void)removeSectionWithIndentifier:(NSString *)identifier;
- (void)removeSection:(CLBTableViewSection *)section;

- (CLBTableViewSection *)sectionAtIndex:(NSInteger)index;
- (CLBTableViewSection *)sectionWithIdentifier:(NSString *)identifier;

- (NSArray *)allSectionIdentifier;
- (NSArray *)allSections;
- (NSInteger)numberOfRowsInTableView;
- (NSInteger)numberOfSectionsInTableView;

- (void)registerTableViewCell:(UITableViewCell *)cell inSectionWithIdentifier:(NSString *)identifier andHeight:(NSInteger)height;

@end
