CLBTableViewSectionController
=============
A simple Objective-C wrapper around the UITableViewController and its protocols to prototype static TableViews on the iOS SDK.

State of the Union
------------------

I currently use parts of the wrapper in production to prototype TableViews in a short amount of time and to avoid to handle the UITableViewDelegate protocol and the UITableViewDataSource protocol as much as I can.

It is especially handy if you use more or less static TableViews with sections: for example a DetailView.

I haven't done any performance testing on it but for my current use cases it works quiet well. Also I can not recommend you to use this if you want to update your cell permanently or if you are adding / removing cells very often.

Feel free to use, fork or contribute and if you're using it let me know. (You can find me on Twitter: @PhilDav)

### Todos
* Making the resize delegate work
* Adding more cell event handlers
* Document all methods so that all options are understandable
* More stuff…


Documentation
-------------

Simply start by cloning the repository and pick the files `CLBTableViewSectionController.h`, `CLBTableViewSectionController.m`, `CLBTableViewSection.h`, `CLBTableViewSection.m` to add them to your project.

### Setup

Import the header files wherever you want to use the controller. It could look like that:


	#import <UIKit/UIKit.h>
	#import "CLBTableViewSectionController.h"
	#import "CLBTableViewSection.h"

	@interface CLBViewController : UIViewController{
    	IBOutlet UITableView *table;
    
   		CLBTableViewSectionController *tableViewController;
	}

	@property (strong, nonatomic) IBOutlet UITableView *table;

	@end

Now you have initialize the section controller and set the `UITableViewDelegate` and the `UITableViewDataSource` to the `CLBTableViewSectionController` so that the section controller can manage the table view.

	tableViewController = [[CLBTableViewSectionController alloc] initWithTableView:table];
    
    [table setDelegate:tableViewController];
    [table setDataSource:tableViewController];

### Add Sections

You can now easily add a section to the TableView

	CLBTableViewSection *section = [[CLBTableViewSection alloc] initWithTitle:@"Title"];
	[tableViewController addSection:section withIdentifier:@"TestSection"];

There are more options to add a section at different position in the table view. I will document them as soon as possible but if you want to check them out have a look into `CLBTableViewSectionController.h`

### Add a cell to a section

After you have created your section it is possible to add a cell to it by using Objective-C blocks.

	[section registerRowWithBlock:^UITableViewCell *(UITableView *tableView) {
       	UITableViewCell *staticTestCell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:@"Test"];
        
        [staticTestCell.textLabel setText:@"Test Cell One"];
        
        return staticTestCell;
    } andHeight:60];

The block will be called if the table view calls `-(UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath` and therefore behaves like it.

You can dequeue a cell from the table view as usual:

	[section registerRowWithBlock:^UITableViewCell *(UITableView *tableView) {
       	UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"theIdentifier"];
		
		if (cell == nil) {
			cell = [UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:@"theIdentifier"];
		}

		[cell.textLabel setText: "Your text in the cell"];
		
        return cell;
    } andHeight:60];

### More
I'll document more of the available methods as soon as I've a little more time. Definitely make sure to check out `CLBTableViewSectionController.h` and `CLBTableViewSection.h` to see which other methods are available. If you have questions or found a bug let me know via GitHub issues or via Twitter (@PhilDav)


License
-------

License
This library is released under the [MIT license](http://www.opensource.org/licenses/MIT).


